@@ -49,8 +49,7 @@ def register(excelFile: "Excel file containing the component data",
                 JSON["alternativeIdentifier"] = r[k]
                 JSON["serialNumber"] = None
             elif k.startswith("B_"):
-                k = k[2:]
-                Batches[k] = r[k]
+                Batches[k[2:]] = r[k]
             else:
                 Properties[k] = r[k]
         JSON['properties'] = Properties
