@@ -407,13 +407,54 @@ def comment(identifier: "ID for the comment to be attached to (can be a ATLAS se
             "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
 
 
+def ship(components: "Component codes",
+         name: "Name of the shipment" = "DESY Shipment",
+         sender: "Sender of the shipment" = "DESYHH",
+         recipient: "Recipient of the shipment" = "AVS",
+         trackingNumber: "Tracking number" = None,
+         shippingService: "Shipping service" = None,
+         type: "Shipment Type (domestic | intraContinental | continental)" = "intraContinental",
+         status: "Current status of the shipment" = "prepared",
+         comments: "Comments" = None):
+    """Ship components to another institute."""
+    try:
+        client = itkdb.Client()
+        if isinstance(components, str):
+            components = [components]
+        assert isinstance(components, list)
+
+        data = {
+            "sender": sender,
+            "name": name,
+            "recipient": recipient,
+            "type": type,
+            "shipmentItems": components}
+
+        if trackingNumber is not None:
+            data["trackingNumber"] = trackingNumber
+        if shippingService is not None:
+            data["shippingService"] = shippingService
+        if comments is not None:
+            data["comments"] = comments
+        client.post('createShipment', data=data)
+
+        logger.info(f"Shipped {components} to {recipient}")
+    except Exception as e:
+        logger.error(e)
+        if len(components) == 1:
+            logger.info("This is probably a DB bug, check if your shipment was created using the web interface.")
+        logger.error("Error while trying to get connection to DB")
+        logger.info(
+            "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
+
+
 def main():
     parser = argh.ArghParser()
     parser.add_commands([authenticate, register, lookup,
                         attach, tests, stage,
                         skeleton, upload, testruns,
                         testfile, assemble, property,
-                        comment])
+                        comment, ship])
     parser.dispatch()
 
 
